/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl;

import de.javagl.swogl.geometry.Ray;


/**
 * Interface for all classes that may provide picking rays that may
 * be sent into a scene, based on a point in screen coordinates.
 * Instances of classes implementing this interface may be passed
 * to the {@link SwoglContainer#create(java.awt.Component, 
 *  SwoglComponentHandler, PickingRayComputer)} method, and will
 * be used by the SwoglContainer to compute the picking rays for
 * the interaction with the SwoglComponents.
 */
public interface PickingRayComputer
{
    /**
     * Returns the picking ray for the given position. The position
     * is given in local screen coordinates.
     * 
     * @param x The x-coordinate
     * @param y The y-coordinate
     * @return The picking ray
     */
    Ray computePickingRay(int x, int y);

}
