/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Insets;
import java.awt.LayoutManager;

/**
 * Simple implementation of the LayoutManager interface that lays out 
 * all visible components side-by-side in their preferred size.
 * This is used in the ContainerPanel of the SwoglContainer.
 */
class SimpleLayout implements LayoutManager
{
    @Override
    public void addLayoutComponent(String name, Component component)
    {
    }

    @Override
    public void removeLayoutComponent(Component component)
    {
    }

    @Override
    public Dimension preferredLayoutSize(Container target)
    {
        synchronized (target.getTreeLock())
        {
            Dimension dim = new Dimension(0, 0);
            int numComponents = target.getComponentCount();
            for (int i = 0; i < numComponents; i++)
            {
                Component component = target.getComponent(i);
                if (component.isVisible())
                {
                    Dimension d = component.getPreferredSize();
                    dim.height = Math.max(dim.height, d.height);
                    dim.width += d.width;
                }
            }
            Insets insets = target.getInsets();
            dim.width += insets.left + insets.right;
            dim.height += insets.top + insets.bottom;
            return dim;
        }
    }

    @Override
    public Dimension minimumLayoutSize(Container target)
    {
        return preferredLayoutSize(target);
    }

    @Override
    public void layoutContainer(Container target)
    {
        synchronized (target.getTreeLock())
        {
            Insets insets = target.getInsets();
            int x = insets.left;

            int numComponents = target.getComponentCount();
            for (int i = 0; i < numComponents; i++)
            {
                Component component = target.getComponent(i);
                if (component.isVisible())
                {
                    Dimension d = component.getPreferredSize();
                    component.setBounds(x, 0, d.width, d.height);
                    x += d.width;
                }
            }
        }
    }
}
