/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl;

import java.awt.Component;

import de.javagl.swogl.scene.Camera;
import de.javagl.swogl.scene.MutableCamera;
import de.javagl.swogl.scene.View;

/**
 * This interface summarizes the implementation-specific parts
 * of a Swogl application. It extends a {@link SwoglSetup}, 
 * which provides the basic elements of a Swogl application.
 * Additionally, it contains a rendering component, a
 * {@link View} configuration and a {@link Camera}. <br />
 * <br />
 * Instances of a SwoglApplication may be created using the
 * factory methods in the {@link SwoglApplications} class,
 * or by directly instantiating a known implementation.
 */
public interface SwoglApplication extends SwoglSetup
{
    /**
     * Returns the component that is used for rendering
     * 
     * @return The component that is used for rendering
     */
    Component getRenderComponent();
    
    /**
     * Returns the view configuration of this application.
     * 
     * @return The view configuration of this application.
     */
    View getView();
    
    /**
     * Returns the Camera of this application.
     * 
     * @return The camera of this application.
     */
    MutableCamera getCamera();
}
