/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl;

import java.util.List;

/**
 * This interface is a {@link SwoglComponentHandler} that additionally
 * allows accessing and rendering the individual 
 * {@link SwoglComponent SwoglComponents}. Instances of classes 
 * implementing this interface are part of a {@link SwoglApplication}.
 */
public interface SwoglRenderer extends SwoglComponentHandler
{
    /**
     * Returns an immutable list of all SwoglComponents. This list also  
     * contains the SwoglComponents that have been passed to 
     * {@link #handleSwoglComponent(SwoglComponent)} but for which no 
     * internal representation has been created yet. The implementation 
     * must make sure that when one of the components from this list is 
     * passed to the {@link #renderSwoglComponent(SwoglComponent)} method, 
     * the component can actually be rendered.
     * 
     * @return An immutable list of all SwoglComponents.
     */
    List<SwoglComponent> getSwoglComponents();
    
    /**
     * Shortcut for <br />
     * <code>
     * for (SwoglComponent s : getSwoglComponents()) renderSwoglComponent(s);
     * </code>
     */
    void renderAllSwoglComponents();

    /**
     * Causes a rendering of the current state of the given SwoglComponent.
     * <br /> 
     * This method should only be called on the thread that is responsible 
     * for rendering and for maintaining the internal representation of the 
     * SwoglComponents.
     * <br /> 
     * Note that call itself does not necessarily cause the rendering of 
     * the specific component, e.g. when the component is internally 
     * maintained as a node in a scene graph. But this method should
     * also make sure that that the dirty regions of Texture and the  
     * Geometry are updated if necessary. Thus, it should be called for  
     * every SwoglComponent that should be rendered, even if the call 
     * may only update the internal representation. 
     * 
     * @param swoglComponent The SwoglComponent to render
     * @throws IllegalArgumentException If the given SwoglComponent is
     * not handled by this class.
     */
    void renderSwoglComponent(SwoglComponent swoglComponent);

}
