/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl;

import java.awt.Rectangle;
import java.awt.image.BufferedImage;

/**
 * Interface for the texture of a SwoglComponent. This interface
 * only maintains a BufferedImage and an associated 'dirty'
 * rectangle. When the image contents is modified, the respective
 * region may be marked as 'dirty', and will be updated at the
 * beginning of the next rendering pass. 
 */
public interface Texture
{
    /**
     * Return the BufferedImage backing this texture. <br />
     * <br />
     * Note: Some renderers may assume that the image is backed by a 
     * DataBufferInt, and thus has to be TYPE_INT_RGB or TYPE_INT_ARGB.
     * 
     * @return The BufferedImage backing this texture
     */
    BufferedImage getImage();
    
    /**
     * Add the given dirty rectangle to this texture. That is, the given
     * rectangle will be merged with any dirty rectangle that may 
     * already be present.
     * 
     * @param rectangle The dirty rectangle
     */
    void addDirtyRectangle(Rectangle rectangle);
    
    /**
     * Returns a copy of the current dirty rectangle. Returns 
     * <code>null</code> if there is no rectangle marked 
     * as 'dirty'
     * 
     * @return A copy of the current dirty rectangle, 
     * or <code>null</code>.
     */
    Rectangle getDirtyRectangle();
    
    /**
     * Clear the current dirty rectangle.
     */
    void clearDirtyRectangle();
}
