/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl.layout;

import de.javagl.swogl.SwoglContainer;


/**
 * This is the common interface for all classes that may lay out
 * SwoglComponents in a SwoglContainer
 */
public interface LayoutManager3D 
{
    /**
     * Lays out the SwoglComponents in a SwoglContainer
     */
    void doLayout3D();
    
    /**
     * This method will assign the given SwoglContainer to this 
     * LayoutManager3D. When this LayoutManager3D is assigned to a 
     * SwoglContainer using the 
     * {@link SwoglContainer#setLayout3D(LayoutManager3D)} method, 
     * the SwoglContainer will pass itself to this method. When a 
     * different LayoutManager3D is assigned to the SwoglContainer,
     * then the SwoglContainer will call this method and pass  
     * <code>null</code> as the argument. This allows implementations  
     * of this interface to perform an initialization when this 
     * LayoutManager3D becomes assigned to a SwoglContainer, and  
     * necessary cleanup operations when it is detached from a 
     * SwoglContainer.
     * 
     * @param swoglContainer The SwoglContainer for this LayoutManager3D
     */
    void setSwoglContainer(SwoglContainer swoglContainer);
}
