/*
 * Swogl - Swing meets OpenGL
 * 
 * Copyright 2007-2011 Marco Hutter - http://swogl.javagl.de
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

package de.javagl.swogl.rendering;

import java.nio.FloatBuffer;

import javax.vecmath.Matrix4f;

import de.javagl.swogl.BufferUtils;
import de.javagl.swogl.MatrixUtils;

/**
 * Utility methods for rendering
 */
class RenderingUtils
{
    /**
     * Direct buffer to temporarily store a matrix
     */
    private static final FloatBuffer tempMatrixBuffer = 
        BufferUtils.createFloatBuffer(16);
    
    /**
     * Returns a direct buffer with the contents of the given matrix.
     * Note that this method is not thread safe. It will always
     * return the same buffer, filled with the given matrix. 
     * The buffer should thus not be stored by clients, but may only
     * be passed to functions which only once read the contents and 
     * do not use the buffer afterwards. 
     * 
     * @param matrix The matrix
     * @return The buffer
     */
    public static FloatBuffer bufferWith(Matrix4f matrix)
    {
        MatrixUtils.writeMatrixToBuffer(matrix, tempMatrixBuffer);
        tempMatrixBuffer.rewind();
        return tempMatrixBuffer;
    }

    /**
     * Private constructor to prevent instantiation
     */
    private RenderingUtils()
    {
    }

}
